@@ -32,10 +32,10 @@ template<typename T>
 struct is_Mat_fixed_only
   {
   typedef char yes[1];
-  typedef char no[2];
+  typedef char  no[2];
   
   template<typename X> static yes& check(typename X::Mat_fixed_type*);
-  template<typename>   static no&  check(...);
+  template<typename>   static  no& check(...);
   
   static const bool value = ( sizeof(check<T>(0)) == sizeof(yes) );
   };
@@ -46,10 +46,10 @@ template<typename T>
 struct is_Row_fixed_only
   {
   typedef char yes[1];
-  typedef char no[2];
+  typedef char  no[2];
   
   template<typename X> static yes& check(typename X::Row_fixed_type*);
-  template<typename>   static no&  check(...);
+  template<typename>   static  no& check(...);
   
   static const bool value = ( sizeof(check<T>(0)) == sizeof(yes) );
   };
@@ -60,10 +60,10 @@ template<typename T>
 struct is_Col_fixed_only
   {
   typedef char yes[1];
-  typedef char no[2];
+  typedef char  no[2];
   
   template<typename X> static yes& check(typename X::Col_fixed_type*);
-  template<typename>   static no&  check(...);
+  template<typename>   static  no& check(...);
   
   static const bool value = ( sizeof(check<T>(0)) == sizeof(yes) );
   };
@@ -300,6 +300,20 @@ template<typename T1, typename op_type>
 struct is_Op< const Op<T1,op_type> >
   { static const bool value = true; };
 
+
+template<typename T>
+struct is_SpToDOp
+  { static const bool value = false; };
+ 
+template<typename T1, typename op_type>
+struct is_SpToDOp< SpToDOp<T1,op_type> >
+  { static const bool value = true; };
+ 
+template<typename T1, typename op_type>
+struct is_SpToDOp< const SpToDOp<T1,op_type> >
+  { static const bool value = true; };
+
+
 template<typename T>
 struct is_eOp
   { static const bool value = false; };
@@ -369,19 +383,6 @@ struct is_mtGlue< const mtGlue<eT, T1, T2, glue_type> >
 //
 
 
-template<typename T>
-struct is_glue_times
-  { static const bool value = false; };
-
-template<typename T1, typename T2>
-struct is_glue_times< Glue<T1,T2,glue_times> >
-  { static const bool value = true; };
-
-template<typename T1, typename T2>
-struct is_glue_times< const Glue<T1,T2,glue_times> >
-  { static const bool value = true; };
-
-
 template<typename T>
 struct is_glue_times_diag
   { static const bool value = false; };
@@ -408,45 +409,6 @@ struct is_op_diagmat< const Op<T1,op_diagmat> >
   { static const bool value = true; };
 
 
-template<typename T>
-struct is_op_strans
-  { static const bool value = false; };
- 
-template<typename T1>
-struct is_op_strans< Op<T1,op_strans> >
-  { static const bool value = true; };
-
-template<typename T1>
-struct is_op_strans< const Op<T1,op_strans> >
-  { static const bool value = true; };
-
-
-template<typename T>
-struct is_op_htrans
-  { static const bool value = false; };
- 
-template<typename T1>
-struct is_op_htrans< Op<T1,op_htrans> >
-  { static const bool value = true; };
-
-template<typename T1>
-struct is_op_htrans< const Op<T1,op_htrans> >
-  { static const bool value = true; };
-
-
-template<typename T>
-struct is_op_htrans2
-  { static const bool value = false; };
- 
-template<typename T1>
-struct is_op_htrans2< Op<T1,op_htrans2> >
-  { static const bool value = true; };
-
-template<typename T1>
-struct is_op_htrans2< const Op<T1,op_htrans2> >
-  { static const bool value = true; };
-
-
 //
 //
 
@@ -536,117 +498,6 @@ struct is_mtGlueCube< mtGlueCube<eT, T1, T2, glue_type> >
 //
 
 
-template<typename T>
-struct is_op_rel
-  { static const bool value = false; };
-
-template<typename out_eT, typename T1>
-struct is_op_rel< mtOp<out_eT, T1, op_rel_lt_pre> >
-  { static const bool value = true; };
-
-template<typename out_eT, typename T1>
-struct is_op_rel< mtOp<out_eT, T1, op_rel_lt_post> >
-  { static const bool value = true; };
-
-template<typename out_eT, typename T1>
-struct is_op_rel< mtOp<out_eT, T1, op_rel_gt_pre> >
-  { static const bool value = true; };
-
-template<typename out_eT, typename T1>
-struct is_op_rel< mtOp<out_eT, T1, op_rel_gt_post> >
-  { static const bool value = true; };
-
-template<typename out_eT, typename T1>
-struct is_op_rel< mtOp<out_eT, T1, op_rel_lteq_pre> >
-  { static const bool value = true; };
-
-template<typename out_eT, typename T1>
-struct is_op_rel< mtOp<out_eT, T1, op_rel_lteq_post> >
-  { static const bool value = true; };
-
-template<typename out_eT, typename T1>
-struct is_op_rel< mtOp<out_eT, T1, op_rel_gteq_pre> >
-  { static const bool value = true; };
-
-template<typename out_eT, typename T1>
-struct is_op_rel< mtOp<out_eT, T1, op_rel_gteq_post> >
-  { static const bool value = true; };
-
-template<typename out_eT, typename T1>
-struct is_op_rel< mtOp<out_eT, T1, op_rel_eq> >
-  { static const bool value = true; };
-
-template<typename out_eT, typename T1>
-struct is_op_rel< mtOp<out_eT, T1, op_rel_noteq> >
-  { static const bool value = true; };
-
-
-
-//
-//
-//
-
-
-
-template<typename T>
-struct is_basevec
-  { static const bool value = ( is_Row_fixed_only<T>::value || is_Col_fixed_only<T>::value ); };
-
-template<typename eT>
-struct is_basevec< Row<eT> >
-  { static const bool value = true; };
-
-template<typename eT>
-struct is_basevec< const Row<eT> >
-  { static const bool value = true; };
-
-template<typename eT>
-struct is_basevec< Col<eT> >
-  { static const bool value = true; };
-
-template<typename eT>
-struct is_basevec< const Col<eT> >
-  { static const bool value = true; };
-  
-template<typename eT>
-struct is_basevec< subview_row<eT> >
-  { static const bool value = true; };
-
-template<typename eT>
-struct is_basevec< const subview_row<eT> >
-  { static const bool value = true; };
-
-template<typename eT>
-struct is_basevec< subview_col<eT> >
-  { static const bool value = true; };
-
-template<typename eT>
-struct is_basevec< const subview_col<eT> >
-  { static const bool value = true; };
-
-template<typename eT>
-struct is_basevec< diagview<eT> >
-  { static const bool value = true; };
-
-template<typename eT>
-struct is_basevec< const diagview<eT> >
-  { static const bool value = true; };
-  
-template<typename eT, typename T1>
-struct is_basevec< subview_elem1<eT,T1> >
-  { static const bool value = true; };
-
-template<typename eT, typename T1>
-struct is_basevec< const subview_elem1<eT,T1> >
-  { static const bool value = true; };
-
-
-//
-//
-//
-
-
-
 template<typename T1>
 struct is_arma_type2
   {
@@ -654,6 +505,7 @@ struct is_arma_type2
   =  is_Mat<T1>::value
   || is_Gen<T1>::value
   || is_Op<T1>::value
+  || is_SpToDOp<T1>::value
   || is_Glue<T1>::value
   || is_eOp<T1>::value
   || is_eGlue<T1>::value
@@ -787,7 +639,16 @@ struct is_mtSpOp
 template<typename eT, typename T1, typename spop_type>
 struct is_mtSpOp< mtSpOp<eT, T1, spop_type> >
   { static const bool value = true; };
+
+
+template<typename T>
+struct is_mtSpGlue
+  { static const bool value = false; };
  
+template<typename eT, typename T1, typename T2, typename spglue_type>
+struct is_mtSpGlue< mtSpGlue<eT, T1, T2, spglue_type> >
+  { static const bool value = true; };
+
 
 
 template<typename T1>
@@ -800,6 +661,7 @@ struct is_arma_sparse_type
   || is_SpOp<T1>::value
   || is_SpGlue<T1>::value
   || is_mtSpOp<T1>::value
+  || is_mtSpGlue<T1>::value
   ;
   };
 
@@ -1030,16 +892,6 @@ struct is_real<double>
 
 
 
-template<typename T1>
-struct is_not_complex
-  { static const bool value = true; };
-
-template<typename eT>
-struct is_not_complex< std::complex<eT> >
-  { static const bool value = false; };
-
-
-
 template<typename T1>
 struct is_complex
   { static const bool value = false; };
@@ -1232,10 +1084,20 @@ struct force_different_type<T1,T1>
 
 
 template<typename T1>
-struct resolves_to_vector_default { static const bool value = false;                    };
+struct resolves_to_vector_default
+  {
+  static const bool value = false;
+  static const bool yes   = false;
+  static const bool no    = true;
+  };
 
 template<typename T1>
-struct resolves_to_vector_test    { static const bool value = T1::is_col || T1::is_row; };
+struct resolves_to_vector_test
+  {
+  static const bool value =  (T1::is_col || T1::is_row || T1::is_xvec);
+  static const bool yes   =  (T1::is_col || T1::is_row || T1::is_xvec);
+  static const bool no    = ((T1::is_col || T1::is_row || T1::is_xvec) == false);
+  };
 
 
 template<typename T1, bool condition>
@@ -1300,71 +1162,6 @@ struct resolves_to_colvector : public resolves_to_colvector_redirect<T1, is_arma
 
 
 
-template<typename glue_type> struct is_glue_mixed_times                   { static const bool value = false; };
-template<>                   struct is_glue_mixed_times<glue_mixed_times> { static const bool value = true;  };
-
-
-
-template<typename glue_type> struct is_glue_mixed_elem { static const bool value = false; };
-
-template<>                   struct is_glue_mixed_elem<glue_mixed_plus>  { static const bool value = true;  };
-template<>                   struct is_glue_mixed_elem<glue_mixed_minus> { static const bool value = true;  };
-template<>                   struct is_glue_mixed_elem<glue_mixed_div>   { static const bool value = true;  };
-template<>                   struct is_glue_mixed_elem<glue_mixed_schur> { static const bool value = true;  };
-
-template<>                   struct is_glue_mixed_elem<glue_rel_lt>    { static const bool value = true; };
-template<>                   struct is_glue_mixed_elem<glue_rel_gt>    { static const bool value = true; };
-template<>                   struct is_glue_mixed_elem<glue_rel_lteq>  { static const bool value = true; };
-template<>                   struct is_glue_mixed_elem<glue_rel_gteq>  { static const bool value = true; };
-template<>                   struct is_glue_mixed_elem<glue_rel_eq>    { static const bool value = true; };
-template<>                   struct is_glue_mixed_elem<glue_rel_noteq> { static const bool value = true; };
-template<>                   struct is_glue_mixed_elem<glue_rel_and>   { static const bool value = true; };
-template<>                   struct is_glue_mixed_elem<glue_rel_or>    { static const bool value = true; };
-
-
-
-template<typename op_type> struct is_op_mixed_elem { static const bool value = false; };
-
-template<>                 struct is_op_mixed_elem<op_cx_scalar_times>      { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_cx_scalar_plus>       { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_cx_scalar_minus_pre>  { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_cx_scalar_minus_post> { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_cx_scalar_div_pre>    { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_cx_scalar_div_post>   { static const bool value = true; };
-
-template<>                 struct is_op_mixed_elem<op_rel_lt_pre>    { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_rel_lt_post>   { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_rel_gt_pre>    { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_rel_gt_post>   { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_rel_lteq_pre>  { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_rel_lteq_post> { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_rel_gteq_pre>  { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_rel_gteq_post> { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_rel_eq>        { static const bool value = true; };
-template<>                 struct is_op_mixed_elem<op_rel_noteq>     { static const bool value = true; };
-
-
-
-template<typename spop_type> struct is_spop_elem                    { static const bool value = false; };
-template<>                   struct is_spop_elem<spop_scalar_times> { static const bool value = true;  };
-
-
-template<typename spglue_type> struct is_spglue_elem                { static const bool value = false; };
-template<>                     struct is_spglue_elem<spglue_plus>   { static const bool value = true;  };
-template<>                     struct is_spglue_elem<spglue_plus2>  { static const bool value = true;  };
-template<>                     struct is_spglue_elem<spglue_minus>  { static const bool value = true;  };
-template<>                     struct is_spglue_elem<spglue_minus2> { static const bool value = true;  };
-
-
-template<typename spglue_type> struct is_spglue_times               { static const bool value = false; };
-template<>                     struct is_spglue_times<spglue_times> { static const bool value = true;  };
-
-
-template<typename spglue_type> struct is_spglue_times2               { static const bool value = false; };
-template<>                     struct is_spglue_times<spglue_times2> { static const bool value = true;  };
-
-
-
 template<typename T1>
 struct is_outer_product
   { static const bool value = false; };
@@ -1393,4 +1190,47 @@ struct has_op_inv< Glue<T1, Op<T2,op_inv>, glue_times> >
 
 
 
+template<typename T1>
+struct has_op_inv_sympd
+  { static const bool value = false; };
+
+template<typename T1>
+struct has_op_inv_sympd< Op<T1,op_inv_sympd> >
+  { static const bool value = true;  };
+
+template<typename T1, typename T2>
+struct has_op_inv_sympd< Glue<Op<T1,op_inv_sympd>, T2, glue_times> >
+  { static const bool value = true;  };
+
+template<typename T1, typename T2>
+struct has_op_inv_sympd< Glue<T1, Op<T2,op_inv_sympd>, glue_times> >
+  { static const bool value = true;  };
+
+
+
+template<typename T>
+struct has_nested_op_traits
+  {
+  typedef char yes[1];
+  typedef char  no[2];
+  
+  template<typename X> static yes& check(typename X::template traits<void>*);
+  template<typename>   static  no& check(...);
+  
+  static const bool value = ( sizeof(check<T>(0)) == sizeof(yes) );
+  };
+
+template<typename T>
+struct has_nested_glue_traits
+  {
+  typedef char yes[1];
+  typedef char  no[2];
+  
+  template<typename X> static yes& check(typename X::template traits<void,void>*);
+  template<typename>   static  no& check(...);
+  
+  static const bool value = ( sizeof(check<T>(0)) == sizeof(yes) );
+  };
+
+
 //! @}
